@@ -27,7 +27,7 @@ def get_stub() -> ResourceStub:
     global stub
     return stub
 
-grpc_host = None
+grpc_host : str = "127.0.0.1:19051"
 
 def set_grpc_host(grpc_host_: str) -> None:
     global grpc_host
@@ -37,7 +37,7 @@ def get_grpc_host() -> str:
     global grpc_host
     return grpc_host
 
-http_host = "54.180.86.146:9011"
+http_host = "127.0.0.1:9011"
 
 def set_http_host(http_host_: str) -> None:
     global http_host
